@@ -4,7 +4,7 @@
 #' Predict the outcome variable at different regressor values (e.g., college
 #' graduates vs. others), and compare those predictions by computing a difference,
 #' ratio, or some other function. `comparisons()` can return many quantities of
-#' interest, such as contrasts, differences, risk ratios, changes in log odds,
+#' interest, such as contrasts, differences, risk ratios, changes in log odds, lift, 
 #' slopes, elasticities, etc.
 #'
 #' * `comparisons()`: unit-level (conditional) estimates.
@@ -29,11 +29,13 @@
 #'     * "sequential": Each factor level is compared to the previous factor level
 #'     * "pairwise": Each factor level is compared to all other levels
 #'     * "minmax": The highest and lowest levels of a factor.
+#'     * "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses.
 #'     * Vector of length 2 with the two values to compare.
 #'   - Logical variables:
 #'     * NULL: contrast between TRUE and FALSE
 #'   - Numeric variables:
 #'     * Numeric of length 1: Contrast for a gap of `x`, computed at the observed value plus and minus `x / 2`. For example, estimating a `+1` contrast compares adjusted predictions when the regressor is equal to its observed value minus 0.5 and its observed value plus 0.5.
+#'     * Numeric of length equal to the number of rows in `newdata`: Same as above, but the contrast can be customized for each row of `newdata`.
 #'     * Numeric vector of length 2: Contrast between the 2nd element and the 1st element of the `x` vector.
 #'     * Data frame with the same number of rows as `newdata`, with two columns of "low" and "high" values to compare.
 #'     * Function which accepts a numeric vector and returns a data frame with two columns of "low" and "high" values to compare. See examples below.
@@ -80,6 +82,8 @@
 #' @template comparison_functions
 #' @template bayesian
 #' @template equivalence
+#' @template type
+#' @template references
 #'
 #' @return A `data.frame` with one row per observation (per term/group) and several columns:
 #' * `rowid`: row number of the `newdata` data frame
@@ -89,6 +93,9 @@
 #' * `dydx`: slope of the outcome with respect to the term, for a given combination of predictor values
 #' * `std.error`: standard errors computed by via the delta method.
 #' * `p.value`: p value associated to the `estimate` column. The null is determined by the `hypothesis` argument (0 by default), and p values are computed before applying the `transform` argument.
+#' * `s.value`: Shannon information transforms of p values. How many consecutive "heads" tosses would provide the same amount of evidence (or "surprise") against the null hypothesis that the coin is fair? The purpose of S is to calibrate the analyst's intuition about the strength of evidence encoded in p against a well-known physical phenomenon. See Greenland (2019) and Cole et al. (2020).
+#' * `conf.low`: lower bound of the confidence interval (or equal-tailed interval for bayesian models)
+#' * `conf.high`: upper bound of the confidence interval (or equal-tailed interval for bayesian models)
 #'
 #' See `?print.marginaleffects` for printing options.
 #'
@@ -185,6 +192,15 @@
 #'     newdata = "mean",
 #'     hypothesis = lc)
 #'
+#' # Effect of a 1 group-wise standard deviation change
+#' # First we calculate the SD in each group of `cyl`
+#' # Second, we use that SD as the treatment size in the `variables` argument
+#' library(dplyr)
+#' mod <- lm(mpg ~ hp + factor(cyl), mtcars)
+#' tmp <- mtcars %>% 
+#'     group_by(cyl) %>%
+#'     mutate(hp_sd = sd(hp))
+#' avg_comparisons(mod, variables = list(hp = tmp$hp_sd), by = "cyl")
 #'
 #' # `by` argument
 #' mod <- lm(mpg ~ hp * am * vs, data = mtcars)
@@ -240,7 +256,7 @@ comparisons <- function(model,
         # if `newdata` is a call to `datagrid`, `typical`, or `counterfactual`,
         # insert `model` should probably not be nested too deeply in the call
         # stack since we eval.parent() (not sure about this)
-        scall <- substitute(newdata)
+        scall <- rlang::enquo(newdata)
         newdata <- sanitize_newdata_call(scall, newdata, model)
 
         model <- sanitize_model(
@@ -274,6 +290,8 @@ comparisons <- function(model,
         cross = cross,
         wts = wts,
         hypothesis = hypothesis,
+        equivalence = equivalence,
+        p_adjust = p_adjust,
         df = df),
         list(...))
     call_attr <- do.call("call", call_attr)
@@ -529,7 +547,7 @@ comparisons <- function(model,
         "rowid", "rowidcf", "group", "term", "hypothesis", "by",
         grep("^contrast", colnames(mfx), value = TRUE),
         bycols,
-        "estimate", "std.error", "statistic", "p.value", "conf.low",
+        "estimate", "std.error", "statistic", "p.value", "s.value", "conf.low",
         "conf.high", "df", "predicted", "predicted_hi", "predicted_lo")
     cols <- intersect(stubcols, colnames(mfx))
     cols <- unique(c(cols, colnames(mfx)))
@@ -628,7 +646,7 @@ avg_comparisons <- function(model,
 
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-    scall <- substitute(newdata)
+    scall <- rlang::enquo(newdata)
     newdata <- sanitize_newdata_call(scall, newdata, model)
 
     # Bootstrap
