@@ -1,9 +1,9 @@
 source("helpers.R")
 using("marginaleffects")
 
-exit_if_not(requiet("margins"))
-exit_if_not(requiet("dplyr"))
-exit_if_not(requiet("ivreg"))
+requiet("margins")
+requiet("poorman")
+requiet("ivreg")
 
 # marginaleffects: vs. margins
 data(Kmenta, package = "ivreg")
@@ -25,10 +25,10 @@ dat <- read.csv(testing_path("stata/databases/ivreg_ivreg_01.csv"))
 stata <- readRDS(testing_path("stata/stata.rds"))[["ivreg_ivreg_01"]]
 mod <- ivreg::ivreg(Q ~ P + D | D + F + A, data = dat)
 ame <- slopes(mod) |>
-   dplyr::group_by(term) |>
-   dplyr::summarize(estimate = mean(estimate),
+   poorman::group_by(term) |>
+   poorman::summarize(estimate = mean(estimate),
              std.error = mean(std.error)) |>
-   dplyr::inner_join(stata, by = "term")
+   poorman::inner_join(stata, by = "term")
 expect_equivalent(ame$estimate, ame$dydxstata, tolerance = 0.0001)
 
 
@@ -50,3 +50,7 @@ mod <- ivreg::ivreg(Q ~ P + D + categ | D + F + A + categ, data = tmp)
 mm <- marginal_means(mod)
 expect_marginal_means(mm)
 
+
+
+
+rm(list = ls())
\ No newline at end of file
